<?php
/**
 * 󥹥ȥ
 */
class {SYL_CLASS}
{
    /**
     * 󥹥ȥ饯
     *
     * @access public
     */
    function {SYL_CLASS}()
    {
    }

    /**
     * å
     *
     * @access public
     * @param object ꥯȥ֥
     * @param object ݡͥȥ᥽åɥ֥
     */
    function execute(&$request, &$cm)
    {
    }

}

?>
